@@ -1,16 +1,17 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* $Id: hdfi.h,v 1.125 1998/02/23 16:29:59 acheng Exp $ */
+/* $Id: hdfi.h 6043 2014-01-21 21:09:03Z acheng $ */
 
 #ifndef HDFI_H
 #define HDFI_H
@@ -47,7 +48,8 @@
 /*      8 - Cray IEEE                                                       */
 /*          (i.e. Big-Endian, all 64-bit architecture w/IEEE Floats)        */
 /*--------------------------------------------------------------------------*/
-#define     DFMT_SUN            0x1111
+#define     DFMT_SUN            0x1111 
+#define     DFMT_SUN_INTEL      0x4441
 #define     DFMT_ALLIANT        0x1111
 #define     DFMT_IRIX           0x1111
 #define     DFMT_APOLLO         0x1111
@@ -61,6 +63,8 @@
 #define     DFMT_VAX            0x2221
 #define     DFMT_MIPSEL         0x4441
 #define     DFMT_PC             0x4441
+#define     DFMT_APPLE          0x1111
+#define     DFMT_APPLE_INTEL    0x4441
 #define     DFMT_MAC            0x1111
 #define     DFMT_SUN386         0x4441
 #define     DFMT_NEXT           0x1111
@@ -68,21 +72,15 @@
 #define     DFMT_ALPHA          0x4441
 #define     DFMT_VP             0x6611
 #define     DFMT_I860           0x4441
-#define     DFMT_CRAYMPP        0x1171
+#define     DFMT_IA64           0x4441
+#define     DFMT_LINUX64        0x4441
+#define     DFMT_POWERPC64      0x1111
 
 /* I/O library constants */
 #define UNIXUNBUFIO 1
 #define UNIXBUFIO   2
 #define MACIO       3
-#define PCIO        4    /* 16-bit MS-DOS File I/O (deprecated) */
-#define WINIO       5    /* 16-bit Windows File I/O (deprecated) */
-#define PAGEBUFIO   6    /* page buffering - fmpool */
-#define WINNTIO     7    /* 32-bit Windows File I/O (deprecated, WinNT now uses UNIXBUFIO) */ 
 
-/* IBM RS6000 AIX hack */
-#if defined(IBM6000) || defined(_AIX)
-#define _POSIX_SOURCE
-#endif 
 
 /* Standard header files needed all the time */
 #include <stdio.h>
@@ -90,11 +88,8 @@
 #include <limits.h>
 #include <string.h>
 
-/* PABLO support files */
-#ifdef HAVE_PABLO
-#define IOTRACE
-#include "IOTrace.h"
-#endif  /* HAVE_PABLO */
+#include "H4api_adpt.h"
+
 
 /*-------------------------------------------------------------------------
  * Define options for each platform
@@ -132,7 +127,11 @@ Please check your Makefile.
 #include <sys/time.h>
 #include <sys/file.h>               /* for unbuffered i/o stuff */
 #include <sys/stat.h>
-#define DF_MT             DFMT_SUN
+#if (defined __sun) && (defined __amd64 || defined __i386) /* SunOS on Intel; 32 and 64-bit modes */
+#define DF_MT   DFMT_SUN_INTEL 
+#else
+#define DF_MT   DFMT_SUN
+#endif /* __sun */
 typedef void              VOID;
 typedef void              *VOIDP;
 typedef char              *_fcd;
@@ -142,21 +141,26 @@ typedef char              int8;
 typedef unsigned char     uint8;
 typedef short int         int16;
 typedef unsigned short int uint16;
+#ifdef _LP64 /* 64-bit environment */
+typedef int               int32;
+typedef unsigned int      uint32;
+#else /* 32-bit environment */
 typedef long int          int32;
 typedef unsigned long int uint32;
+#endif
 typedef int               intn;
 typedef unsigned int      uintn;
 typedef int               intf;     /* size of INTEGERs in Fortran compiler */
 typedef float             float32;
 typedef double            float64;
+#ifdef _LP64 /* 64-bit environment */
+typedef long              hdf_pint_t;   /* an integer the same size as a pointer */
+#else /* 32-bit environment */
 typedef int               hdf_pint_t;   /* an integer the same size as a pointer */
+#endif
 #define FNAME_POST_UNDERSCORE
 #define _fcdtocp(desc) (desc)
-#ifdef  HAVE_FMPOOL
-#define FILELIB PAGEBUFIO  /* enable page buffering */
-#else
 #define FILELIB UNIXBUFIO
-#endif
 
 /* JPEG #define's - Look in the JPEG docs before changing - (Q) */
 
@@ -209,11 +213,7 @@ typedef double            float64;
 typedef int               hdf_pint_t;   /* an integer the same size as a pointer */
 #define FNAME_POST_UNDERSCORE
 #define _fcdtocp(desc) (desc)
-#ifdef  HAVE_FMPOOL
-#define FILELIB PAGEBUFIO  /* enable page buffering */
-#else
 #define FILELIB UNIXBUFIO
-#endif
 
 /* JPEG #define's - Look in the JPEG docs before changing - (Q) */
 
@@ -253,26 +253,28 @@ Please check your Makefile.
 typedef void              VOID;
 typedef void              *VOIDP;
 typedef char              *_fcd;
+#ifndef _ALL_SOURCE       
+typedef char              int8;
+typedef short int         int16; 
+typedef int               int32;
+#endif  
 typedef char              char8;
 typedef unsigned char     uchar8;
-typedef char              int8;
 typedef unsigned char     uint8;
-typedef short int         int16;
 typedef unsigned short int uint16;
-typedef long int          int32;
-typedef unsigned long int uint32;
+typedef unsigned int      uint32;
 typedef int               intn;
 typedef unsigned int      uintn;
 typedef float             float32;
 typedef double            float64;
 typedef int               intf;     /* size of INTEGERs in Fortran compiler */
+#ifdef AIX5L64
+typedef long              hdf_pint_t;   /* an integer the same size as a pointer */
+#else /*AIX5L64 */
 typedef int               hdf_pint_t;   /* an integer the same size as a pointer */
+#endif /*AIX5L64 */
 #define _fcdtocp(desc) (desc)
-#ifdef  HAVE_FMPOOL
-#define FILELIB PAGEBUFIO  /* enable page buffering */
-#else
 #define FILELIB UNIXBUFIO
-#endif
 
 /* JPEG #define's - Look in the JPEG docs before changing - (Q) */
 
@@ -298,7 +300,9 @@ Please check your Makefile.
 #endif
 #define GOT_MACHINE
 
+#ifndef HAVE_UNISTD_H
 #define HAVE_UNISTD_H  /* unistd.h - close, fork,..etc */
+#endif
 
 #   define BSD
 #ifndef __GNUC__
@@ -316,20 +320,25 @@ typedef char              int8;
 typedef unsigned char     uint8;
 typedef short int         int16;
 typedef unsigned short int uint16;
+#ifdef _LP64 /* 64-bit environment */
+typedef int               int32;
+typedef unsigned int      uint32;
+#else /* 32-bit environment */
 typedef long int          int32;
 typedef unsigned long int uint32;
+#endif
 typedef int               intn;
 typedef unsigned int      uintn;
 typedef float             float32;
 typedef double            float64;
 typedef int               intf;     /* size of INTEGERs in Fortran compiler */
+#ifdef _LP64 /* 64-bit environment */
+typedef long              hdf_pint_t;   /* an integer the same size as a pointer */
+#else /* 32-bit environment */
 typedef int               hdf_pint_t;   /* an integer the same size as a pointer */
-#define _fcdtocp(desc) (desc)
-#ifdef  HAVE_FMPOOL
-#define FILELIB PAGEBUFIO  /* enable page buffering */
-#else
-#define FILELIB UNIXBUFIO
 #endif
+#define _fcdtocp(desc) (desc)
+#define FILELIB UNIXBUFIO
 
 /* JPEG #define's - Look in the JPEG docs before changing - (Q) */
 
@@ -361,7 +370,14 @@ Please check your Makefile.
 #endif
 #define GOT_MACHINE 1
 
-#   define BSD
+/*
+ * BSD was originally defined with no value.  But some newer SGI system
+ * header files (e.g., resolv.h) assume it has a value and evaluate it
+ * in expressions, thus causing compiling errors.  This has been reported
+ * to SGI as bug #781568.  SGI could not provide a list of the semantics
+ * of BSD values and suggested a work around of setting BSD to 1.
+ */
+#   define BSD 1
 #ifndef __GNUC__
 #include <memory.h>
 #endif /* __GNUC__ */
@@ -387,14 +403,12 @@ typedef int                intf;     /* size of INTEGERs in Fortran compiler */
 typedef long               hdf_pint_t;   /* an integer the same size as a pointer */
 #define FNAME_POST_UNDERSCORE
 #define _fcdtocp(desc) (desc)
-#ifdef  HAVE_FMPOOL
-#define FILELIB PAGEBUFIO  /* enable page buffering */
-#else
 #define FILELIB UNIXBUFIO
-#endif
+/*
 #ifdef IRIX64
 #define BIG_LONGS
 #endif
+*/
 
 
 /* JPEG #define's - Look in the JPEG docs before changing - (Q) */
@@ -409,184 +423,19 @@ typedef long               hdf_pint_t;   /* an integer the same size as a pointe
 
 #endif /* IRIX */
 
-#if (defined(UNICOS) || defined(_UNICOS)) && !defined(_CRAYMPP)
-
-#ifndef UNICOS
-#define UNICOS
+/* CRAY XT3
+ * Note from RedStorm helpdesk,
+ * When I compile a C code with the '-v' option, it indicates that the compile
+ * is done with the macros __QK_USER__ and __LIBCATAMOUNT__ defined.  In
+ * addition, there are other macros like __x86_64__ defined as well, to
+ * indicate processor type.  __QK_USER__ might be a good check for Catamount,
+ * and __x86_64__ might be good for Opteron node.  You might try something
+ * like the following in a header file:
+ */
+#if ((defined(__QK_USER__)) && (defined(__x86_64__)))
+#define __CRAY_XT3__
 #endif
 
-#ifdef GOT_MACHINE
-If you get an error on this line more than one machine type has been defined.
-Please check your Makefile.
-#endif
-#define GOT_MACHINE 1
-
-#include <memory.h>
-#include <fortran.h>
-#ifndef O_RDONLY
-#include <fcntl.h>              /* for unbuffered i/o stuff */
-#define L_INCR  1
-#include <sys/stat.h>
-#endif /*O_RDONLY*/
-
-#ifdef _CRAYIEEE
-#define DF_MT   DFMT_UNICOSIEEE
-#else
-#define DF_MT   DFMT_UNICOS
-#endif
-typedef void            VOID;
-typedef void            *VOIDP;
-#ifdef OLD_WAY /* May need to be included on other machines than the C-90 */
-typedef char            *_fcd;
-#endif /* OLD_WAY */
-typedef signed char     char8;
-typedef unsigned char   uchar8;
-typedef signed char     int8;
-typedef unsigned char   uint8;
-typedef int             int16;
-typedef unsigned int    uint16;
-typedef int             int32;
-typedef unsigned int    uint32;
-typedef int             intn;
-typedef unsigned int    uintn;
-typedef float           float32;
-typedef double          float64;
-typedef int             intf;     /* size of INTEGERs in Fortran compiler */
-typedef int               hdf_pint_t;   /* an integer the same size as a pointer */
-
-#define DF_CAPFNAMES            /* fortran names are in all caps */
-#ifdef  HAVE_FMPOOL
-#define FILELIB PAGEBUFIO  /* enable page buffering */
-#else
-#define FILELIB UNIXBUFIO
-#endif
-
-/* JPEG #define's - Look in the JPEG docs before changing - (Q) */
-
-/* Determine the memory manager we are going to use. Valid values are: */
-/*  MEM_DOS, MEM_ANSI, MEM_NAME, MEM_NOBS.  See the JPEG docs for details on */
-/*  what each does */
-#define JMEMSYS         MEM_ANSI
-#define RIGHT_SHIFT_IS_UNSIGNED
-#define CHAR_IS_UNSIGNED
-
-#endif /* UNICOS */
-
-#if defined(_CRAYMPP)
-
-#ifndef CRAYMPP
-#define CRAYMPP
-#endif
-
-#ifdef GOT_MACHINE
-If you get an error on this line more than one machine type has been defined.
-Please check your Makefile.
-#endif
-#define GOT_MACHINE 1
-
-#include <string.h>
-#include <limits.h>
-#include <memory.h>
-#include <fortran.h>
-#ifndef O_RDONLY
-#include <fcntl.h>              /* for unbuffered i/o stuff */
-#define L_INCR  1
-#include <sys/stat.h>
-#endif /*O_RDONLY*/
-
-#define DF_MT   DFMT_CRAYMPP
-typedef void            VOID;
-typedef void            *VOIDP;
-#ifdef OLD_WAY /* May need to be included on other machines than the C-90 */
-typedef char            *_fcd;
-#endif /* OLD_WAY */
-typedef signed char     char8;
-typedef unsigned char   uchar8;
-typedef signed char     int8;
-typedef unsigned char   uint8;
-typedef short           int16;
-typedef unsigned short  uint16;
-typedef short           int32;
-typedef unsigned short  uint32;
-typedef int             intn;
-typedef unsigned int    uintn;
-typedef float           float32;
-typedef double          float64;
-typedef int             intf;     /* size of INTEGERs in Fortran compiler */
-typedef int               hdf_pint_t;   /* an integer the same size as a pointer */
-
-#define _HUGE              /* This should only be defined to a value on the PC */
-#define DF_CAPFNAMES            /* fortran names are in all caps */
-#ifdef  HAVE_FMPOOL
-#define FILELIB PAGEBUFIO  /* enable page buffering */
-#else
-#define FILELIB UNIXBUFIO
-#endif
-
-/* JPEG #define's - Look in the JPEG docs before changing - (Q) */
-
-/* Determine the memory manager we are going to use. Valid values are: */
-/*  MEM_DOS, MEM_ANSI, MEM_NAME, MEM_NOBS.  See the JPEG docs for details on */
-/*  what each does */
-#define JMEMSYS         MEM_ANSI
-#define RIGHT_SHIFT_IS_UNSIGNED
-#define CHAR_IS_UNSIGNED
-
-#endif /* CRAYMPP */
-
-#if defined(VMS) || defined(vms)
-
-#ifdef GOT_MACHINE
-If you get an error on this line more than one machine type has been defined.
-Please check your Makefile.
-#endif
-#define GOT_MACHINE 1
-#include <file.h>               /* for unbuffered i/o stuff */
-#include <sys/stat.h>
-#define DF_MT              DFMT_VAX
-typedef void               VOID;
-typedef void               *VOIDP;
-typedef char               *_fcd;
-typedef char               char8;
-typedef unsigned char      uchar8;
-typedef char               int8;
-typedef unsigned char      uint8;
-typedef short int          int16;
-typedef unsigned short int uint16;
-#ifdef __alpha
-typedef int                int32;
-typedef unsigned int       uint32;
-typedef long              hdf_pint_t;   /* an integer the same size as a pointer */
-#else
-typedef long int           int32;
-typedef unsigned long int  uint32;
-typedef int               hdf_pint_t;   /* an integer the same size as a pointer */
-#endif
-typedef int                intn;
-typedef unsigned int       uintn;
-typedef float              float32;
-typedef double             float64;
-typedef int                intf;     /* size of INTEGERs in Fortran compiler */
-#define _fcdtocp(desc)  ((char *) *((char **) &desc[4]))
-
-/* 
-  Redef a couple of C routine names to avoid conflicts
-  since the VMS link command is case-insensitive
-*/
-#define FILELIB UNIXBUFIO
-#define DF_CAPFNAMES            /* fortran names are in all caps */
-#include "dfivms.h"
-
-
-/* JPEG #define's - Look in the JPEG docs before changing - (Q) */
-
-/* Determine the memory manager we are going to use. Valid values are: */
-/*  MEM_DOS, MEM_ANSI, MEM_NAME, MEM_NOBS.  See the JPEG docs for details on */
-/*  what each does */
-#define JMEMSYS         MEM_ANSI
-
-#endif /* VMS */
-
 #if defined(CONVEX) || defined(CONVEXNATIVE) || defined(__convexc__)
 
 #ifndef CONVEX
@@ -625,11 +474,7 @@ typedef double            float64;
 typedef int               intf;     /* size of INTEGERs in Fortran compiler */
 typedef int               hdf_pint_t;   /* an integer the same size as a pointer */
 #define _fcdtocp(desc) (desc)
-#ifdef  HAVE_FMPOOL
-#define FILELIB PAGEBUFIO  /* enable page buffering */
-#else
 #define FILELIB UNIXBUFIO
-#endif
 
 /* JPEG #define's - Look in the JPEG docs before changing - (Q) */
 
@@ -643,13 +488,17 @@ typedef int               hdf_pint_t;   /* an integer the same size as a pointer
 
 #endif /* CONVEX */
 
+ 
+#if defined (__APPLE__)
 
-#if defined(MIPSEL) || ((defined(mips) || defined(__mips)) && (defined(ultrix) || defined(__ultrix)))
-
-#ifndef MIPSEL
-#define MIPSEL
+#ifndef __APPLE__
+#define __APPLE__
+#endif
+#ifdef __LITTLE_ENDIAN__
+#define DF_MT DFMT_APPLE_INTEL
+#else
+#define DF_MT DFMT_APPLE
 #endif
-
 #ifdef GOT_MACHINE
 If you get an error on this line more than one machine type has been defined.
 Please check your Makefile.
@@ -663,7 +512,12 @@ Please check your Makefile.
 #include <sys/types.h>
 #include <sys/file.h>               /* for unbuffered i/o stuff */
 #include <sys/stat.h>
-#define DF_MT   DFMT_MIPSEL
+#ifdef __i386
+#ifndef INTEL86
+#define INTEL86   /* we need this Intel define or bad things happen later */
+#endif /* INTEL86 */
+#endif /* __i386 */
+
 typedef void            VOID;
 typedef void            *VOIDP;
 typedef char            *_fcd;
@@ -680,14 +534,9 @@ typedef unsigned int    uintn;
 typedef float           float32;
 typedef double          float64;
 typedef int             intf;     /* size of INTEGERs in Fortran compiler */
-typedef int               hdf_pint_t;   /* an integer the same size as a pointer */
+typedef long            hdf_pint_t;   /* an integer the same size as a pointer */
 #define _fcdtocp(desc) (desc)
-#define FNAME_POST_UNDERSCORE
-#ifdef  HAVE_FMPOOL
-#define FILELIB PAGEBUFIO  /* enable page buffering */
-#else
 #define FILELIB UNIXBUFIO
-#endif
 
 /* JPEG #define's - Look in the JPEG docs before changing - (Q) */
 
@@ -696,69 +545,14 @@ typedef int               hdf_pint_t;   /* an integer the same size as a pointer
 /*  what each does */
 #define JMEMSYS         MEM_ANSI
 
-#endif /* MIPSEL */
+#endif /* __APPLE__ */
 
-#if defined(MAC) || defined(macintosh) || defined (SYMANTEC_C)
 
-#ifdef GOT_MACHINE
-If you get an error on this line more than one machine type has been defined.
-Please check your Makefile.
-#endif
-#define GOT_MACHINE 1
-
-#include <memory.h>             /* malloc stuff for MPW */
-#include <fcntl.h>              /* unbuffered I/O stuff for MPW */
-#ifdef __MWERKS__				/* Metrowerks */
-#include <sioux.h>
-#include <console.h>
-#endif
-#ifdef SYMANTEC_C				/* for SYMANTEC C */
-#include <unix.h>
-#define isascii(c)  (isprint(c) || iscntrl(c))
-#else  /* MPW, possibly others */
-#include <Files.h>              /* for unbuffered I/O stuff */
-#endif /* SYMANTEC_C*/
-#ifndef ABSOFT
-#define DF_CAPFNAMES            /* fortran names are in all caps */
-#endif /* ABSOFT */
-#define DF_DYNAMIC              /* use dynamic allocation */
-#define DF_MT   DFMT_MAC
-
-typedef void              VOID;
-typedef void              *VOIDP;
-typedef char              *_fcd;
-typedef char              char8;
-typedef unsigned char     uchar8;
-typedef char              int8;
-typedef unsigned char     uint8;
-typedef short int         int16;
-typedef unsigned short int uint16;
-typedef long int          int32;
-typedef unsigned long int uint32;
-typedef int               intn;
-typedef unsigned int      uintn;
-typedef float             float32;
-typedef double            float64;
-typedef int               intf;     /* size of INTEGERs in Fortran compiler */
-typedef int               hdf_pint_t;   /* an integer the same size as a pointer */
-#define _fcdtocp(desc) (desc)
-void exit(int status);
-
-#define FILELIB MACIO
-
-/* JPEG #define's - Look in the JPEG docs before changing - (Q) */
-
-/* Determine the memory manager we are going to use. Valid values are: */
-/*  MEM_DOS, MEM_ANSI, MEM_NAME, MEM_NOBS.  See the JPEG docs for details on */
-/*  what each does */
-#define JMEMSYS         MEM_ANSI
-
-#endif /*MAC*/
 
 /* Metrowerks Mac compiler defines some PC stuff so need to exclude this on the Mac */
-#if !(defined(macintosh) || defined(MAC))
+#if !(defined (__APPLE__))
 
-#if defined INTEL86 || defined M_I86 || defined M_I386 || defined DOS386 || defined __i386 || defined UNIX386
+#if defined _M_ALPHA || defined _M_X64 || defined _M_IA64 || defined _M_IX86 || defined INTEL86 || defined M_I86 || defined M_I386 || defined DOS386 || defined __i386 || defined UNIX386 || defined i386
 #ifndef INTEL86
 #define INTEL86
 #endif /* INTEL86 */
@@ -771,9 +565,9 @@ void exit(int status);
 #define DOS386
 #endif /* M_I386 && !DOS386 */
 
-#if defined _WINDOWS || defined WIN32
+#if defined _WINDOWS || defined _WIN32
 #define WIN386
-#endif  /* _WINDOWS | WIN32 */
+#endif  /* _WINDOWS | _WIN32 */
 
 #if defined WIN386 || defined DOS386 || defined UNIX386
 #define INTEL386
@@ -785,6 +579,10 @@ Please check your Makefile.
 #endif
 #define GOT_MACHINE 1
 
+#if defined _WINDOWS || defined _WIN32
+#pragma comment( lib, "oldnames" )
+#endif
+
 #include <fcntl.h>
 #ifdef UNIX386
 #include <sys/types.h>      /* for unbuffered file I/O */
@@ -801,6 +599,8 @@ Please check your Makefile.
 #ifdef __WATCOMC__
 #include <stddef.h>         /* for the 'fortran' pragma */
 #endif
+
+
 #if defined WIN386
 #ifndef GMEM_MOVEABLE       /* check if windows header is already included */
 #include <windows.h>        /* include the windows headers */
@@ -829,20 +629,29 @@ typedef unsigned int      uintn;
 typedef float             float32;
 typedef double            float64;
 typedef long              intf;     /* size of INTEGERs in Fortran compiler */
-typedef int               hdf_pint_t;   /* an integer the same size as a pointer */
+#ifdef _WIN64
+typedef long long         hdf_pint_t;   /* 8-byte pointer */
+#else
+typedef int               hdf_pint_t;   /* 4-byte pointer */
+#endif /* _WIN64 */
+
+#if defined _M_ALPHA
+#define FNAME_PRE_UNDERSCORE
+#endif
 
 #if defined UNIX386
+#ifdef H4_ABSOFT
+#define FNAME(x) x
+#define DF_CAPFNAMES
+#else
 #define FNAME_POST_UNDERSCORE
+#endif
 #elif defined INTEL386
 #define DF_CAPFNAMES
 #endif
 #define _fcdtocp(desc) (desc)
 
-#ifdef  HAVE_FMPOOL
-#define FILELIB PAGEBUFIO  /* enable page buffering */
-#else
 #define FILELIB UNIXBUFIO
-#endif
 
 /* JPEG #define's - Look in the JPEG docs before changing - (Q) */
 
@@ -854,8 +663,9 @@ typedef int               hdf_pint_t;   /* an integer the same size as a pointer
 #define INCLUDES_ARE_ANSI
 
 #endif /* INTEL86 */
-#endif /* !(defined(macintosh) || defined(MAC)) */
+#endif /* !(defined(__APPLE__)) */
 
+/*-----------------------------------------------------*/
 #if defined(NEXT) || defined(NeXT)
 
 #ifndef NEXT
@@ -894,11 +704,7 @@ typedef double            float64;
 typedef int               hdf_pint_t;   /* an integer the same size as a pointer */
 #define FNAME_POST_UNDERSCORE
 #define _fcdtocp(desc) (desc)
-#ifdef  HAVE_FMPOOL
-#define FILELIB PAGEBUFIO  /* enable page buffering */
-#else
 #define FILELIB UNIXBUFIO
-#endif
 
 /* JPEG #define's - Look in the JPEG docs before changing - (Q) */
 
@@ -912,6 +718,7 @@ typedef int               hdf_pint_t;   /* an integer the same size as a pointer
 
 #endif /* NEXT */
 
+/*-----------------------------------------------------*/
 #if defined(MOTOROLA) || defined(m88k)
 
 #ifdef GOT_MACHINE
@@ -960,6 +767,7 @@ typedef int               hdf_pint_t;   /* an integer the same size as a pointer
 
 #endif /* MOTOROLA */
 
+/*-----------------------------------------------------*/
 #if defined DEC_ALPHA || (defined __alpha && defined __unix__)
 
 #ifndef DEC_ALPHA
@@ -996,11 +804,7 @@ typedef double            float64;
 typedef long              hdf_pint_t;   /* an integer the same size as a pointer */
 #define FNAME_POST_UNDERSCORE
 #define _fcdtocp(desc) (desc)
-#ifdef  HAVE_FMPOOL
-#define FILELIB PAGEBUFIO  /* enable page buffering */
-#else
 #define FILELIB UNIXBUFIO
-#endif
 
 /* JPEG #define's - Look in the JPEG docs before changing - (Q) */
 
@@ -1016,6 +820,7 @@ typedef long              hdf_pint_t;   /* an integer the same size as a pointer
 
 #endif /* DEC_ALPHA */
 
+/*-----------------------------------------------------*/
 #if defined VP | defined __uxpm__
 
 #ifndef VP
@@ -1062,6 +867,7 @@ typedef int               hdf_pint_t;   /* an integer the same size as a pointer
 
 #endif /* VP */
 
+/*-----------------------------------------------------*/
 #if defined I860 | defined i860
 
 #ifndef I860
@@ -1109,6 +915,202 @@ typedef int               hdf_pint_t;   /* an integer the same size as a pointer
 
 #endif /* I860 */
 
+
+/*-----------------------------------------------------*/
+/* Power PC 5 64 */
+#if defined __powerpc64__
+
+#ifdef GOT_MACHINE
+If you get an error on this line more than one machine type has been defined.
+Please check your Makefile.
+#endif
+#define GOT_MACHINE
+
+#include <sys/file.h>               /* for unbuffered i/o stuff */
+#include <sys/stat.h>
+#define DF_MT             DFMT_POWERPC64
+typedef void              VOID;
+typedef void              *VOIDP;
+typedef char              *_fcd;
+typedef char              char8;
+typedef unsigned char     uchar8;
+typedef char              int8;
+typedef unsigned char     uint8;
+typedef short int         int16;
+typedef unsigned short int uint16;
+typedef int               int32;
+typedef unsigned int      uint32;
+typedef int               intn;
+typedef unsigned int      uintn;
+typedef int               intf;     /* size of INTEGERs in Fortran compiler */
+typedef float             float32;
+typedef double            float64;
+typedef long              hdf_pint_t;   /* an integer the same size as a pointer */
+#if defined __GNUC__
+#define FNAME_POST_UNDERSCORE
+#endif
+#define _fcdtocp(desc) (desc)
+#define FILELIB UNIXBUFIO
+
+/* JPEG #define's - Look in the JPEG docs before changing - (Q) */
+
+/* Determine the memory manager we are going to use. Valid values are: */
+/*  MEM_DOS, MEM_ANSI, MEM_NAME, MEM_NOBS.  See the JPEG docs for details on */
+/*  what each does */
+#define JMEMSYS         MEM_ANSI
+
+#ifdef __GNUC__
+#define HAVE_STDC
+#define INCLUDES_ARE_ANSI
+#endif
+
+/*-----------------------------------------------------*/
+#endif /*power PC 5 64 */
+/* Linux 64 */
+#if defined(__linux__) && defined __x86_64__  && !(defined  SUN)  /* i.e. 64-bit Linux  but not SunOS on Intel */
+
+#ifdef GOT_MACHINE
+If you get an error on this line more than one machine type has been defined.
+Please check your Makefile.
+#endif
+#define GOT_MACHINE
+
+#include <sys/file.h>               /* for unbuffered i/o stuff */
+#include <sys/stat.h>
+#define DF_MT             DFMT_LINUX64
+typedef void              VOID;
+typedef void              *VOIDP;
+typedef char              *_fcd;
+typedef char              char8;
+typedef unsigned char     uchar8;
+typedef char              int8;
+typedef unsigned char     uint8;
+typedef short int         int16;
+typedef unsigned short int uint16;
+typedef int               int32;
+typedef unsigned int      uint32;
+typedef int               intn;
+typedef unsigned int      uintn;
+typedef int               intf;     /* size of INTEGERs in Fortran compiler */
+typedef float             float32;
+typedef double            float64;
+typedef long              hdf_pint_t;   /* an integer the same size as a pointer */
+#define FNAME_POST_UNDERSCORE
+#define _fcdtocp(desc) (desc)
+#define FILELIB UNIXBUFIO
+
+/* JPEG #define's - Look in the JPEG docs before changing - (Q) */
+
+/* Determine the memory manager we are going to use. Valid values are: */
+/*  MEM_DOS, MEM_ANSI, MEM_NAME, MEM_NOBS.  See the JPEG docs for details on */
+/*  what each does */
+#define JMEMSYS         MEM_ANSI
+
+#ifdef __GNUC__
+#define HAVE_STDC
+#define INCLUDES_ARE_ANSI
+#endif
+
+#endif /*Linux 64 */
+
+/*-----------------------------------------------------*/
+/* 64-bit Free BSD */
+
+#if defined __FreeBSD__ && defined __x86_64__
+
+#ifdef GOT_MACHINE
+If you get an error on this line more than one machine type has been defined.
+Please check your Makefile.
+#endif
+#define GOT_MACHINE
+
+#include <sys/file.h>               /* for unbuffered i/o stuff */
+#include <sys/stat.h>
+#define DF_MT             DFMT_LINUX64
+typedef void              VOID;
+typedef void              *VOIDP;
+typedef char              *_fcd;
+typedef char              char8;
+typedef unsigned char     uchar8;
+typedef char              int8;
+typedef unsigned char     uint8;
+typedef short int         int16;
+typedef unsigned short int uint16;
+typedef int               int32;
+typedef unsigned int      uint32;
+typedef int               intn;
+typedef unsigned int      uintn;
+typedef int               intf;     /* size of INTEGERs in Fortran compiler */
+typedef float             float32;
+typedef double            float64;
+typedef long              hdf_pint_t;   /* an integer the same size as a pointer */
+#define FNAME_POST_UNDERSCORE
+#define _fcdtocp(desc) (desc)
+#define FILELIB UNIXBUFIO
+
+/* JPEG #define's - Look in the JPEG docs before changing - (Q) */
+
+/* Determine the memory manager we are going to use. Valid values are: */
+/*  MEM_DOS, MEM_ANSI, MEM_NAME, MEM_NOBS.  See the JPEG docs for details on */
+/*  what each does */
+#define JMEMSYS         MEM_ANSI
+
+#ifdef __GNUC__
+#define HAVE_STDC
+#define INCLUDES_ARE_ANSI
+#endif
+
+#endif /*64-bit FreeBSD */
+
+/*-----------------------------------------------------*/
+
+/* IA64 running Linux */
+#if defined __ia64 && !(defined(hpux) || defined(__hpux))
+
+#ifdef GOT_MACHINE
+If you get an error on this line more than one machine type has been defined.
+Please check your Makefile.
+#endif
+#define GOT_MACHINE
+
+#include <sys/file.h>               /* for unbuffered i/o stuff */
+#include <sys/stat.h>
+#define DF_MT             DFMT_IA64
+typedef void              VOID;
+typedef void              *VOIDP;
+typedef char              *_fcd;
+typedef char              char8;
+typedef unsigned char     uchar8;
+typedef char              int8;
+typedef unsigned char     uint8;
+typedef short int         int16;
+typedef unsigned short int uint16;
+typedef int               int32;
+typedef unsigned int      uint32;
+typedef int               intn;
+typedef unsigned int      uintn;
+typedef int               intf;     /* size of INTEGERs in Fortran compiler */
+typedef float             float32;
+typedef double            float64;
+typedef long              hdf_pint_t;   /* an integer the same size as a pointer */
+#define FNAME_POST_UNDERSCORE
+#define _fcdtocp(desc) (desc)
+#define FILELIB UNIXBUFIO
+
+/* JPEG #define's - Look in the JPEG docs before changing - (Q) */
+
+/* Determine the memory manager we are going to use. Valid values are: */
+/*  MEM_DOS, MEM_ANSI, MEM_NAME, MEM_NOBS.  See the JPEG docs for details on */
+/*  what each does */
+#define JMEMSYS         MEM_ANSI
+
+#ifdef __GNUC__
+#define HAVE_STDC
+#define INCLUDES_ARE_ANSI
+#endif
+
+#endif /* IA64 */
+
 #ifndef GOT_MACHINE
 No machine type has been defined.  Your Makefile needs to have someing like
 -DSUN or -DUNICOS in order for the HDF internal structures to be defined
@@ -1158,7 +1160,7 @@ correctly.
         (i) |= (uint16)(*(p) & 0xff); (p)++; }
 
 #   define INT32DECODE(p, i) \
-{ (i) = ((*(p) & 0x80) ? ~0xffffffff : 0x00) | ((int32)(*(p) & 0xff) << 24); (p)++; \
+{ (i) = (int32)(((int32)*(p) & 0x80) ? ~0xffffffff : 0x00) | ((int32)(*(p) & 0xff) << 24); (p)++; \
         (i) |= ((int32)(*(p) & 0xff) << 16); (p)++; \
         (i) |= ((int32)(*(p) & 0xff) << 8); (p)++; \
         (i) |= (*(p) & 0xff); (p)++; }
@@ -1174,21 +1176,9 @@ correctly.
 #   define NBYTEDECODE(s, d, n) \
 {   HDmemcpy(d,s,n); p+=n }
 
-/**************************************************************************
-*                   Conversion Routine Pointers
-***************************************************************************/
-#    ifndef DFKMASTER
-extern int (*DFKnumin)(const void * source, void * dest, uint32 num_elm,
-            uint32 source_stride,uint32 dest_stride);
-extern int (*DFKnumout)(const void * source, void * dest, uint32 num_elm,
-            uint32 source_stride,uint32 dest_stride);
-#     endif /* DFKMASTER */
-
 /*----------------------------------------------------------------
 ** MACRO FCALLKEYW for any special fortran-C stub keyword
 **
-** MacIntosh MPW LS-fortran needs pascal since it can interface
-**  best with pascal functions.
 ** Microsoft C and Fortran need __fortran for Fortran callable C
 **  routines.
 **
@@ -1199,13 +1189,6 @@ extern int (*DFKnumout)(const void * source, void * dest, uint32 num_elm,
 #undef FRETVAL
 #endif
 
-#if defined(MAC)                /* with LS FORTRAN */
-#ifndef ABSOFT
-#   define FCALLKEYW    pascal
-#   define FRETVAL(x)   pascal x
-#endif /* ABSOFT */
-#endif
-
 #ifndef FRETVAL /* !MAC */
 #   define FCALLKEYW    /*NONE*/
 #   define FRETVAL(x)   x
@@ -1268,7 +1251,7 @@ extern int (*DFKnumout)(const void * source, void * dest, uint32 num_elm,
 /**************************************************************************
 *  Allocation functions defined differently 
 **************************************************************************/
-#if !defined MALLOC_CHECK
+#if !defined(MALLOC_CHECK)
 #  define HDmalloc(s)      (malloc((size_t)s))
 #  define HDcalloc(a,b)    (calloc((size_t)a,(size_t)b))
 #  define HDfree(p)        (free((void*)p))
@@ -1291,9 +1274,9 @@ extern int (*DFKnumout)(const void * source, void * dest, uint32 num_elm,
 #  define HDstrrchr(s,c)        (strrchr((s),(c)))
 #  define HDstrtol(s,e,b)       (strtol((s),(e),(b)))
 /* non-standard function, not defined on the following machines - */
-#if !(defined VMS || defined macintosh || defined MAC || defined SYMANTEC_C || defined MIPSEL || defined NEXT || defined CONVEX || defined IBM6000 || defined ANSISUN || defined IRIX)
+#if !(defined IBM6000 || defined ANSISUN )
 #  define HDstrdup(s)      ((char *)strdup((const char *)(s)))
-#endif /* !(VMS | etc..) */
+#endif /* !(etc..) */
 
 
 /**************************************************************************
@@ -1308,11 +1291,7 @@ extern int (*DFKnumout)(const void * source, void * dest, uint32 num_elm,
 /**************************************************************************
 *  Misc. functions
 **************************************************************************/
-#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C)
-#define HDstat(path, result)	(mstat(path))
-#else /* !macintosh */
 #define HDstat(path, result)	(stat(path, result))
-#endif /* !macintosh */
 #define HDgetenv(s1)            (getenv(s1))
 #define HDputenv(s1)            (putenv(s1))
 #define HDltoa(v)               (ltoa(v))
